Clazz.declarePackage("JSV.dialog");
(function(){
var c$ = Clazz.declareType(JSV.dialog, "DialogParams", null);
})();
;//5.0.1-v7 Tue Sep 16 15:25:55 CDT 2025
